@@ -96,9 +96,7 @@ BltState_Xe_Hpm::~BltState_Xe_Hpm()
 //!
 MOS_STATUS BltState_Xe_Hpm::Initialize()
 {
-    BLT_CHK_STATUS_RETURN(BltState::Initialize());
     initialized = true;
-
     return MOS_STATUS_SUCCESS;
 }
 
@@ -632,6 +630,10 @@ MOS_STATUS BltState_Xe_Hpm::SubmitCMD(
         &createOption));
     // Set GPU context
     BLT_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(m_osInterface, MOS_GPU_CONTEXT_BLT));
+    // Register context with the Batch Buffer completion event
+    BLT_CHK_STATUS_RETURN(m_osInterface->pfnRegisterBBCompleteNotifyEvent(
+        m_osInterface,
+        MOS_GPU_CONTEXT_BLT));
 
     // Initialize the command buffer struct
     MOS_ZeroMemory(&cmdBuffer, sizeof(MOS_COMMAND_BUFFER));
