@@ -54,8 +54,6 @@ MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::Init(void *settings)
     return MOS_STATUS_SUCCESS;
 }
 
-
-
 MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::Prepare(void *params)
 {
     ENCODE_FUNC_CALL();
@@ -95,7 +93,7 @@ MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::Prepare(void *params)
 
     inputParameters.numberTilesInFrame = numTileRows * numTileColumns;
 
-    m_statusReport->Init(&inputParameters);
+    ENCODE_CHK_STATUS_RETURN(m_statusReport->Init(&inputParameters));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -104,6 +102,25 @@ MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::Execute()
 {
     ENCODE_FUNC_CALL();
 
+    ENCODE_CHK_NULL_RETURN(m_featureManager);
+    auto superResFeature = dynamic_cast<Av1SuperRes *>(m_featureManager->GetFeature(Av1FeatureIDs::av1SuperRes));
+    ENCODE_CHK_NULL_RETURN(superResFeature);
+    if (superResFeature->IsEnabled())
+    {
+        if (superResFeature->IsSuperResUsed())
+        {
+            MEDIA_SFC_INTERFACE_MODE sfcMode = {};
+            sfcMode.vdboxSfcEnabled          = false;
+            sfcMode.veboxSfcEnabled          = true;
+            if (!m_sfcItf->IsRenderInitialized())
+            {
+                m_sfcItf->Initialize(sfcMode);
+            }
+            ENCODE_CHK_STATUS_RETURN(m_sfcItf->Render(superResFeature->GetDownScalingParams()));
+            ContextSwitchBack();
+        }
+    }
+
     ENCODE_CHK_STATUS_RETURN(ActivateVdencVideoPackets());
     ENCODE_CHK_STATUS_RETURN(ExecuteActivePackets());
 
@@ -142,14 +159,6 @@ MOS_STATUS Av1VdencPipelineXe_Lpm_Plus_Base::ActivateVdencVideoPackets()
 #endif
     }
 
-    auto superResFeature = dynamic_cast<Av1SuperRes *>(m_featureManager->GetFeature(Av1FeatureIDs::av1SuperRes));
-    ENCODE_CHK_NULL_RETURN(superResFeature);
-
-    if (superResFeature->IsEnabled())
-    {
-        ENCODE_CHK_STATUS_RETURN(ActivatePacket(Av1Superres, immediateSubmit, 0, 0));
-    }
-
     if (brcFeature->IsBRCInitRequired())
     {
         ENCODE_CHK_STATUS_RETURN(ActivatePacket(Av1HucBrcInit, immediateSubmit, 0, 0));
