@@ -1102,6 +1102,18 @@ public:
 #endif  // MOS_MESSAGES_ENABLED
     );
 
+    static MOS_STATUS FreeResource(
+        OsDeviceContext       *osDeviceContext,
+        MOS_RESOURCE_HANDLE    resource,
+        uint32_t               flag
+#if MOS_MESSAGES_ENABLED
+        ,
+        const char            *functionName,
+        const char            *filename,
+        int32_t                line
+#endif  // MOS_MESSAGES_ENABLED
+    );
+
     //!
     //! \brief    Get Resource Info
     //! \details  [Resource Interface] Get the info of a graphic resource.
@@ -1129,14 +1141,10 @@ public:
     //! \details  [Resource Interface] Lock the gfx resource for CPU to access
     //! \details  Caller: HAL only
     //! \details  A sys memory ptr will be provided by this interface if executed successfully.
-    //! \details  The sys memory is mapped to the gfx memory inside MOS module. 
+    //! \details  The sys memory is mapped to the gfx memory inside MOS module.
     //! \details  This interface is usually for driver to read/write data into a resource directly (without program HW cmd).
-    //! \details  Caller must make sure no access out of bound of the locked out data. UnlockResource must be called when finished access the locked data.
-    //!           A resource already been locked cannot be locked again. 
-    //!           This is a blocking call if the resource is used by the cmdbuffer which already submitted to an existing GPU context.
-    //!           Unless SkipResourceSync is called. This interface will make sure the sync of Lock.
-    //! \details  If the resource is compressed, gfx memory decompression will be triggered.
-    //!           
+    //! \details  This interface will call the overloading LockMosResource for MOS.
+    //!
     //! \param    [in] streamState
     //!           Handle of Os Stream State
     //! \param    [in] resource
@@ -1148,9 +1156,37 @@ public:
     //!           Locked memory data pointer, nullptr if lock failed.
     //!
     static void *LockMosResource(
-        MOS_STREAM_HANDLE streamState,
+        MOS_STREAM_HANDLE   streamState,
         MOS_RESOURCE_HANDLE resource,
-        PMOS_LOCK_PARAMS flags);
+        PMOS_LOCK_PARAMS    flags);
+    //!
+    //! \brief    Lock Resource
+    //! \details  [Resource Interface] Lock the gfx resource for CPU to access
+    //! \details  Caller: MOS only
+    //! \details  A sys memory ptr will be provided by this interface if executed successfully.
+    //! \details  The sys memory is mapped to the gfx memory inside MOS module.
+    //! \details  This interface is usually for driver to read/write data into a resource directly (without program HW cmd).
+    //! \details  Caller must make sure no access out of bound of the locked out data. UnlockResource must be called when finished access the locked data.
+    //!           A resource already been locked cannot be locked again.
+    //!           This is a blocking call if the resource is used by the cmdbuffer which already submitted to an existing GPU context.
+    //!           Unless SkipResourceSync is called. This interface will make sure the sync of Lock.
+    //! \details  If the resource is compressed, gfx memory decompression will be triggered.
+    //!
+    //! \param    [in] OsDeviceContext
+    //!           Os Device Context
+    //! \param    [in] resource
+    //!           MOS Resource handle of the resource to lock.
+    //! \param    [in] flags
+    //!           Control flags of locking resource.
+    //!
+    //! \return   void *
+    //!           Locked memory data pointer, nullptr if lock failed.
+    //!
+    static void *LockMosResource(
+        OsDeviceContext       *osDeviceContext,
+        MOS_RESOURCE_HANDLE    resource,
+        PMOS_LOCK_PARAMS       flags,
+        bool                   isDumpPacket=0);
 
     //!
     //! \brief    Unlock Resource
@@ -1159,6 +1195,7 @@ public:
     //! \details  UnlockResource must be called when finished access the locked data of the resource.
     //!           A resource already been unlocked cannot be unlocked again. 
     //! \details  Unlock resource will not trigger compressing or changing the layout of the resource.
+    //! \details  This interface will call the overloading UnlockMosResource for MOS.
     //!           
     //! \param    [in] streamState
     //!           Handle of Os Stream State
@@ -1171,7 +1208,25 @@ public:
     static MOS_STATUS UnlockMosResource(
         MOS_STREAM_HANDLE streamState,
         MOS_RESOURCE_HANDLE resource);
-
+    //!
+    //! \brief    Unlock Resource
+    //! \details  [Resource Interface] Unlock the gfx resource which is locked out.
+    //! \details  Caller: MOS only
+    //! \details  UnlockResource must be called when finished access the locked data of the resource.
+    //!           A resource already been unlocked cannot be unlocked again.
+    //! \details  Unlock resource will not trigger compressing or changing the layout of the resource.
+    //!
+    //! \param    [in] OsDeviceContext
+    //!           Os Device Context
+    //! \param    [in] resource
+    //!           MOS Resource handle of the allocated resource.
+    //!
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    static MOS_STATUS UnlockMosResource(
+        OsDeviceContext    *osDeviceContext,
+        MOS_RESOURCE_HANDLE    resource);
     //!
     //! \brief    Update resource usage type
     //! \details  update the resource usage for cache policy
@@ -2094,6 +2149,7 @@ public:
 
     //! \brief    Get usersetting instance for each stream
     //! \details  the user setting instance
+    //! \details  call the overloading MosGetUserSettingInstance for osDeviceContext
     //! \param    MOS_STREAM_HANDLE streamState
     //!           [in] streamState
     //! \return   MediaUserSettingSharedPtr - user setting instance
@@ -2101,6 +2157,15 @@ public:
     static MediaUserSettingSharedPtr MosGetUserSettingInstance(
         MOS_STREAM_HANDLE streamState);
 
+    //! \brief    Get usersetting instance for each stream
+    //! \details  the user setting instance
+    //! \param    OsDeviceContext osDeviceContext
+    //!           [in] osDeviceContext
+    //! \return   MediaUserSettingSharedPtr - user setting instance
+    //!
+    static MediaUserSettingSharedPtr MosGetUserSettingInstance(
+        OsDeviceContext *osDeviceContext);
+
     //! \brief    Get usersetting instance for each stream
     //! \details  the user setting instance
     //! \param    PMOS_CONTEXT mosCtx
